==> custom_search-7.x-1.1.tar.gz: custom_search/custom_search.js <==
// $Id: custom_search.js,v 1.1.4.1 2010/03/04 10:34:13 jdanthinne Exp $

(function($) {
  Drupal.behaviors.custom_search = {
    attach: function(context) {

      // Check if the search box is not empty on submit
      $('#search-block-form', context)
        .submit(function(){
          var box = $(this).find('input:text');
          if (box.val() == '' || box.val() == Drupal.settings.custom_search.default_value) {
            $(this).find('input:text').addClass('error');
            return false;
          }
          return true;
        }
      );

      // Clear default text on focus, and put it back on blur.
      $('#search-block-form input:text')
        .blur(function(){
          if ($(this).val() == '') {
            $(this).addClass('custom-search-default-value');
            $(this).val(Drupal.settings.custom_search.default_value);
          }
        })
        .focus(function(){
          if ($(this).val() == Drupal.settings.custom_search.default_value) $(this).val('');
          $(this).removeClass('custom-search-default-value');
        }
      );

      // Handle checkboxes
      $('.custom-search-selector input:checkbox').each(function(){
        var el = $(this);
        if (el.val() == 'c-all') {
          el.change(function(){
            $(this).parents('.custom-search-selector').find('input:checkbox[value!=c-all]').attr('checked', false);
          });
        }
        else {
          if (el.val().substr(0,2) == 'c-') {
            el.change(function(){
              $('.custom-search-selector input:checkbox').each(function(){
                if ($(this).val().substr(0,2) == 'o-') $(this).attr('checked', false);
              });
              $(this).parents('.custom-search-selector').find('input:checkbox[value=c-all]').attr('checked', false);
            });
          } else {
            el.change(function(){
              $(this).parents('.custom-search-selector').find('input:checkbox[value!='+el.val()+']').attr('checked', false);
            });
          }
        }
      });

      // Reselect types and terms in advanced search
      var edit_keys = $('#edit-keys').val();
      if(edit_keys) {
        // types
        var pos = edit_keys.indexOf('type:');
        if (pos) {
          var pos2 = edit_keys.indexOf(' ',pos);
          if (pos2==-1) pos2 = edit_keys.length;
          var types = edit_keys.substring(pos+5,pos2);
          types = types.split(',');
          for (var i in types) {
            $('.search-form input:checkbox[value='+types[i]+']').attr('checked', true);
          }
        }
        // terms
        var pos = edit_keys.indexOf('term:');
        if (pos) {
          var pos2 = edit_keys.indexOf(' ',pos);
          if (pos2==-1) pos2 = edit_keys.length;
          var terms = edit_keys.substring(pos+5,pos2);
          terms = terms.split(',');
          for (var i in terms) {
            $('#edit-term option[value='+terms[i]+']').attr('selected', true);
          }
        }
      }

    }
  }
})(jQuery);

==> custom_search-7.x-1.2.tar.gz: custom_search/custom_search.js <==
// $Id: custom_search.js,v 1.1.4.2 2010/03/17 16:11:36 jdanthinne Exp $

(function($) {
  Drupal.behaviors.custom_search = {
    attach: function(context) {

      // Check if the search box is not empty on submit
      $('#search-block-form', context)
        .submit(function(){
          var box = $(this).find('input:text');
          if (box.val() == '' || box.val() == Drupal.settings.custom_search[$(this).attr('id') + "_default_value"]) {
            $(this).find('input:text').addClass('error');
            return false;
          }
          return true;
        }
      );

      // Clear default text on focus, and put it back on blur.
      $('#search-block-form input:text')
        .blur(function(){
          if ($(this).val() == '') {
            $(this).addClass('custom-search-default-value');
            $(this).val(Drupal.settings.custom_search[$(this).parents('form').attr('id') + "_default_value"]);
          }
        })
        .focus(function(){
          if ($(this).val() == Drupal.settings.custom_search[$(this).parents('form').attr('id') + "_default_value"]) $(this).val('');
          $(this).removeClass('custom-search-default-value');
        }
      );

      // Handle checkboxes
      $('.custom-search-selector input:checkbox').each(function(){
        var el = $(this);
        if (el.val() == 'c-all') {
          el.change(function(){
            $(this).parents('.custom-search-selector').find('input:checkbox[value!=c-all]').attr('checked', false);
          });
        }
        else {
          if (el.val().substr(0,2) == 'c-') {
            el.change(function(){
              $('.custom-search-selector input:checkbox').each(function(){
                if ($(this).val().substr(0,2) == 'o-') $(this).attr('checked', false);
              });
              $(this).parents('.custom-search-selector').find('input:checkbox[value=c-all]').attr('checked', false);
            });
          } else {
            el.change(function(){
              $(this).parents('.custom-search-selector').find('input:checkbox[value!='+el.val()+']').attr('checked', false);
            });
          }
        }
      });

      // Reselect types and terms in advanced search
      var edit_keys = $('#edit-keys').val();
      if(edit_keys) {
        // types
        var pos = edit_keys.indexOf('type:');
        if (pos) {
          var pos2 = edit_keys.indexOf(' ',pos);
          if (pos2==-1) pos2 = edit_keys.length;
          var types = edit_keys.substring(pos+5,pos2);
          types = types.split(',');
          for (var i in types) {
            $('.search-form input:checkbox[value='+types[i]+']').attr('checked', true);
          }
        }
        // terms
        var pos = edit_keys.indexOf('term:');
        if (pos) {
          var pos2 = edit_keys.indexOf(' ',pos);
          if (pos2==-1) pos2 = edit_keys.length;
          var terms = edit_keys.substring(pos+5,pos2);
          terms = terms.split(',');
          for (var i in terms) {
            $('#edit-term option[value='+terms[i]+']').attr('selected', true);
          }
        }
      }

    }
  }
})(jQuery);
